| Copyright | (c) Sergey Kolbasov 2019 |
|---|---|
| License | Apache License 2.0 |
| Safe Haskell | None |
| Language | Haskell2010 |
Linnet.Conduit
Contents
Description
Synopsis
- streamBody :: forall m i. MonadIO m => Endpoint m (ConduitT i ByteString m ())
Documentation
streamBody :: forall m i. MonadIO m => Endpoint m (ConduitT i ByteString m ()) Source #
Endpoint that reads chunked request body as ConduitT stream of lazy ByteString. Matches if body is chunked.
Beware that it also pauses slowloris timeout in Warp as it reads request body using lazy IO.
Orphan instances
| (Encode ct a, KnownSymbol ct, NaturalTransformation m IO, MonadIO m) => ToResponse ct (ConduitT () a m ()) Source # | |
Methods toResponse :: ConduitT () a m () -> Response # | |
| (Encode ApplicationJson a, NaturalTransformation m IO, MonadIO m) => ToResponse ApplicationJson (ConduitT () a m ()) Source # | |
Methods toResponse :: ConduitT () a m () -> Response # | |